@plone-gray-light:                          lighten(#000, 46.5%);
@plone-link-color:                          #007bb3;  //plone blue
@plone-gray-lighter:                        lighten(#000, 80%);  // #ccc //disableds like

//*// TOOLBAR
@plone-toolbar-bg:                          rgba(0,0,0,.9);
@plone-toolbar-submenu-bg:                  rgba(20,20,20,.95);
@plone-toolbar-font-primary:                'Roboto Condensed', sans-serif;
@plone-toolbar-font-secondary:              'Roboto', sans-serif;
@plone-toolbar-separator-color:             rgba(255,255,255,.17);
@plone-toolbar-link:                        @plone-link-color;
@plone-toolbar-text-color:                  rgba(255,255,255,.9);
@plone-toolbar-submenu-text-color:          #fff;
@plone-toolbar-submenu-header-color:        lighten(#000, 80%);
@plone-toolbar-published-color:             @plone-link-color;  // published and external same color
@plone-toolbar-draft-color:                 #fab82a;  // lime-yellow //draft is visible
@plone-toolbar-pending-color:               #e2e721;  // orange
@plone-toolbar-private-color:               #c4183c;  // red
@plone-toolbar-internal-color:              #fab82a;  // is draft
@plone-toolbar-internally-published-color:  #883dfa;  // is intranet

@plone-screen-xs-max:                       (@plone-screen-sm-min + 1);
@plone-screen-xs-min:                       480px;
@plone-screen-sm-min:                       768px;
@plone-screen-md-min:                       992px;
@plone-screen-lg-min:                       1200px;

@plone-left-toolbar-expanded:               120px;
@plone-left-toolbar:                        60px;
@plone-toolbar-submenu-width:               180px;


//*// DEVICES
@plone-container-sm:                        750px;
@plone-container-md:                        970px;
@plone-container-lg:                        1170px;
