//*// import some vars for the toolbar, we use a local copy here:
//@import url("https://raw.githubusercontent.com/plone/Products.CMFPlone/master/Products/CMFPlone/static/patterns/toolbar/src/css/variables.less");
@import "plone.toolbar.vars.less";
@import "theme.less";
